@@ -17,15 +17,13 @@ MainWindow::MainWindow(QWidget *parent) :
     channel_(1)
 {
 #ifdef Q_WS_MAEMO_5
-    QDBusConnection::systemBus().connect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
-                                         MCE_DEVICE_ORIENTATION_SIG,
-                                         this,
-                                         SLOT(orientationChanged(QString)));
+    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 #endif
 
     ui->setupUi(this);
 
     timer_ = new QTimer(this);
+    taptimer_.start();
 
     // Time signatures...
     for (int i = 1 ; i < 17 ; ++i) {
@@ -54,6 +52,8 @@ MainWindow::MainWindow(QWidget *parent) :
     connect(timer_, SIGNAL(timeout()), this, SLOT(onTimeout()));
     connect(ui->comboTS1, SIGNAL(currentIndexChanged(int)), this, SLOT(onTimeSigChange(int)));
     connect(ui->comboTS2, SIGNAL(currentIndexChanged(int)), this, SLOT(onTimeSigChange(int)));
+    connect(ui->btnTap, SIGNAL(clicked()), this, SLOT(onTapClicked()));
+
 
     // Load previous BPM and time signature
     QSettings sett("maetronome/maetronome");
@@ -61,6 +61,7 @@ MainWindow::MainWindow(QWidget *parent) :
     bpm_ = sett.value("history/bpm", QVariant(120)).toInt(&bOK);
     timesiq1_ = sett.value("history/timesig1", QVariant(4)).toInt(&bOK);
     timesiq2_ = sett.value("history/timesig2", QVariant(4)).toInt(&bOK);
+    ui->actionHigh_pitch_click->setChecked(sett.value("history/highpitch", QVariant(true)).toBool());
 
     int tmp = 3;
     if ( timesiq2_ < 8 ) {
@@ -80,6 +81,7 @@ MainWindow::~MainWindow()
     sett.setValue("history/bpm", bpm_);
     sett.setValue("history/timesig1", timesiq1_);
     sett.setValue("history/timesig2", timesiq2_);
+    sett.setValue("history/highpitch", ui->actionHigh_pitch_click->isChecked());
 
     // Shutdown SDL
     while(Mix_Playing(channel_) != 0);
@@ -134,9 +136,11 @@ void MainWindow::onBtnMinus() {
 void MainWindow::onTimeout() {
     //Play our sound file, and capture the channel on which it is played
     Mix_HaltChannel(1);
-    if (counter_)
-      channel_ = Mix_PlayChannel(1, sound_, 0);
-    else channel_ = Mix_PlayChannel(1, sound2_, 0);
+
+    if (!counter_ && ui->actionHigh_pitch_click->isChecked())
+      channel_ = Mix_PlayChannel(1, sound2_, 0);
+    else channel_ = Mix_PlayChannel(1, sound_, 0);
+
     if(channel_ == -1) {
         printf("Unable to play WAV file: %s\n", Mix_GetError());
     }
@@ -176,43 +180,21 @@ void MainWindow::onTimeSigChange(int i) {
     counter_ = 0;
 }
 
+// Tap button clicked
+void MainWindow::onTapClicked() {
+    int elapsed = taptimer_.restart();
 
-#ifdef Q_WS_MAEMO_5
-// Portrait/landscape for maemo5
-void MainWindow::setLandscape() {
-    setAttribute(Qt::WA_Maemo5ForceLandscapeOrientation, true);
-}
-
-void MainWindow::setPortrait() {
-    setAttribute(Qt::WA_Maemo5ForcePortraitOrientation, true);
-}
-
-void MainWindow::orientationChanged(const QString &newOrientation)
-{
-    if (newOrientation == QLatin1String(MCE_ORIENTATION_PORTRAIT))
-        setPortrait();
-    else
-        setLandscape();
-}
-
-bool MainWindow::event(QEvent *ev) {
-    switch (ev->type()) {
-    case QEvent::WindowActivate:
-        QDBusConnection::systemBus().call(
-                QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
-                                               MCE_REQUEST_IF,
-                                               MCE_ACCELEROMETER_ENABLE_REQ));
-        break;
-    case QEvent::WindowDeactivate:
-        QDBusConnection::systemBus().call(
-                QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
-                                               MCE_REQUEST_IF,
-                                               MCE_ACCELEROMETER_DISABLE_REQ));
-        break;
-    default:
-        break;
+    if ( elapsed > 2500 ) {
+        return;
+    }
+    else if ( elapsed > 1500 ) {
+        elapsed = 1500;
+    }
+    else if ( elapsed < 240 ) {
+        elapsed = 240;
     }
 
-    return QWidget::event(ev);
+    int tempo = (int)(60.0 / (elapsed / 1000.0));
+    ui->horizontalSlider->setValue(tempo);
+
 }
-#endif
