@@ -3,20 +3,13 @@
 
 #include <QMainWindow>
 #include <QTimer>
+#include <QTime>
 
 #include "SDL/SDL.h"
 #include "SDL/SDL_mixer.h"
 
 #include <QtGui>
 
-#ifdef Q_WS_MAEMO_5
-#include <QtDBus>
-#include <QtMaemo5>
-
-#include <mce/mode-names.h>
-#include <mce/dbus-names.h>
-#endif
-
 namespace Ui {
     class MainWindow;
 }
@@ -37,17 +30,12 @@ public slots:
     void onTimeout();
     void onSliderChanged(int value);
     void onTimeSigChange(int i);
+    void onTapClicked();
     void onBtnPlus();
     void onBtnMinus();
-#ifdef Q_WS_MAEMO_5
-    void orientationChanged(const QString &newOrientation);
-#endif
 
 protected:
     void changeEvent(QEvent *e);
-#ifdef Q_WS_MAEMO_5
-    bool event(QEvent *ev);
-#endif
 
 private:
     Ui::MainWindow *ui;
@@ -60,6 +48,9 @@ private:
     bool started_;
     int counter_;
 
+    // Tap tempo stuff
+    QTime taptimer_;
+
     Mix_Chunk *sound_;
     Mix_Chunk *sound2_;
     int channel_;
